@@ -48,6 +48,7 @@
 #include "action-callbacks.h"
 #include "plugin.h"
 #include "search-box.h"
+#include "search-files.h"
 #include "anjuta-bookmarks.h"
 
 #define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-document-manager.xml"
@@ -278,7 +279,10 @@ static GtkActionEntry actions_search[] = {
 	G_CALLBACK (on_search_previous)},
   { "ActionSearchboxPopupClearHighlight", GTK_STOCK_FIND, N_("Clear Highlight"),
 	NULL, N_("Clear all highlighted text"),
-	G_CALLBACK (on_search_popup_clear_highlight)}
+	G_CALLBACK (on_search_popup_clear_highlight)},
+  { "ActionEditFindFiles", GTK_STOCK_FIND_AND_REPLACE, N_("Find in Files"),
+	NULL, N_("Search in project files"),
+	G_CALLBACK (on_search_find_in_files)}
 };
 
 static GtkToggleActionEntry actions_searchbox_popup[] = {
@@ -533,6 +537,9 @@ value_added_project_root_uri (AnjutaPlugin *plugin, const gchar *name,
 	g_free (doc_plugin->project_path);
 	doc_plugin->project_name = NULL;
 
+	if (doc_plugin->search_files)
+		search_files_update_project (SEARCH_FILES(doc_plugin->search_files));
+	
 	root_uri = g_value_get_string (value);
 	if (root_uri)
 	{
@@ -563,6 +570,10 @@ value_removed_project_root_uri (AnjutaPlugin *plugin, const gchar *name,
 	g_free (doc_plugin->project_name);
 	doc_plugin->project_name = NULL;
 
+	if (doc_plugin->search_files)
+		search_files_update_project (SEARCH_FILES(doc_plugin->search_files));
+
+	
 	update_title(doc_plugin);
 }
 
@@ -1407,13 +1418,12 @@ on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
 				file = ianjuta_file_get_file (IANJUTA_FILE (te), NULL);
 				if (file)
 				{
-					gchar *uri;
-					gchar* file_uri = g_file_get_uri (file);
 					/* Save line locations also */
-					uri = g_strdup_printf ("%s#%d", file_uri,
-										  ianjuta_editor_get_lineno (te, NULL));
-					files = g_list_prepend (files, uri);
-					g_free (file_uri);
+					gchar *line_number;
+
+					line_number = g_strdup_printf ("%d", ianjuta_editor_get_lineno (te, NULL));
+					files = g_list_prepend (files, anjuta_session_get_relative_uri_from_file (session, file, line_number));
+					g_free (line_number);
 				}
 			}
 		}
@@ -1650,7 +1660,7 @@ activate_plugin (AnjutaPlugin *plugin)
 	gint i;
 	static gboolean initialized = FALSE;
 	GList *actions, *act;
-
+	
 	DEBUG_PRINT ("%s", "DocmanPlugin: Activating document manager plugin…");
 
 	dplugin = ANJUTA_PLUGIN_DOCMAN (plugin);
@@ -1660,7 +1670,7 @@ activate_plugin (AnjutaPlugin *plugin)
 	docman = anjuta_docman_new (dplugin);
 	dplugin->docman = docman;
 
-	ANJUTA_DOCMAN(docman)->shell = plugin->shell;
+	ANJUTA_DOCMAN(docman)->shell = anjuta_plugin_get_shell(plugin);
 	g_signal_connect (G_OBJECT (docman), "document-added",
 					  G_CALLBACK (on_document_added), plugin);
 	g_signal_connect (G_OBJECT (docman), "document-changed",
@@ -1730,16 +1740,14 @@ activate_plugin (AnjutaPlugin *plugin)
 	/* Create the default searchbox instance, but don't yet put it into
 	   dplugin->vbox, to prevent the box being displayed at session start */
 	dplugin->search_box = search_box_new (ANJUTA_DOCMAN (docman));
-
+	
 	/* Setup popup menu */
 	popup_menu = gtk_ui_manager_get_widget (GTK_UI_MANAGER (ui),
 											"/PopupDocumentManager");
 	g_assert (popup_menu != NULL && GTK_IS_MENU (popup_menu));
 	anjuta_docman_set_popup_menu (ANJUTA_DOCMAN (docman), popup_menu);
 
-	if (!initialized)
-	{
-	}
+
 	/* Connect to save session */
 	g_signal_connect (G_OBJECT (plugin->shell), "save-session",
 					  G_CALLBACK (on_session_save), plugin);
